-- airport.lua: Cleaner Costs [nclok1405]

CLEANERCOST_SR2 = 1
CLEANERCOST_SRTT = 2
CLEANERCOST_SRIV = 3
CLEANERCOST_SRGOOH = 4

-- Kill Cost Table
-- I don't know how it really works in PAYDAY2 but I think it varies between missions and difficulties
CLEANERCOST_TABLE = {1000, 3000, 6000, 10000, 20000, 30000, 40000, 50000, 100000, 250000, 500000, 1000000}

Cleanercost_game = 1
Cleanercost_last_message_handle = {}
Cleanercost_kill_count = 0

function airport_init()
end

-- debug function - call from the console with 'lua' command
function warp_airport()
	message("warping...")
	delay(0)
	teleport("#PLAYER#", "airport_$nav-warp")
end

-- Main Thread
-- Run it by `thread_new("airport_main")` from sr3_city_main() in SRTT/IV
function airport_main()
	-- Find out which game we're playing
	if MAX_NOTORIETY_LEVEL == 5 then
		-- If max notoriety is 5...
		Cleanercost_game = CLEANERCOST_SR2	-- Assume SR2 by default
		
		-- If there is a function named "set_stag_active" then we're in SRTT
		for func, v in pairs(_G) do
			if func == "set_stag_active" then
				Cleanercost_game = CLEANERCOST_SRTT
				break
			end
		end
	elseif MAX_NOTORIETY_LEVEL == 6 then
		-- If max notoriety is 6...
		Cleanercost_game = CLEANERCOST_SRIV	-- Assume SRIV by default
		
		-- If there is a function named "extraction_reset" then we're in SRGOOH
		for func, v in pairs(_G) do
			if func == "extraction_reset" then
				Cleanercost_game = CLEANERCOST_SRGOOH
				break
			end
		end
	end

	while true do
		thread_yield()
		
		-- Register notoriety event for every frame
		on_notoriety_event("cleanercost_notoriety_event_local", LOCAL_PLAYER)
		if coop_is_active() then
			on_notoriety_event("cleanercost_notoriety_event_remote", REMOTE_PLAYER)
		end
	end
end

-- Called when the players commit crime. This is the only way I could do to detect random ped kills in SR2.
function cleanercost_notoriety_event_local(event, police, gang, team)
	cleanercost_notoriety_event_do(LOCAL_PLAYER, event, police, gang, team)
end
function cleanercost_notoriety_event_remote(event, police, gang, team)
	cleanercost_notoriety_event_do(REMOTE_PLAYER, event, police, gang, team)
end
function cleanercost_notoriety_event_do(player, event, police, gang, team)
	if event == "civilian kill" then
		Cleanercost_kill_count = Cleanercost_kill_count + 1
		
		local idx = Cleanercost_kill_count
		if idx < 1 then
			idx = 1
		end
		if idx > sizeof_table(CLEANERCOST_TABLE) then
			idx = sizeof_table(CLEANERCOST_TABLE)
		end
		local cost = CLEANERCOST_TABLE[idx]
		cash_remove(cost, player)
		
		local msg = "CIVILIAN KILLED!\nDEDUCTING $"..cost.." IN CLEANER COSTS"
		cleanercost_message(msg, 5, player, false)
	end
end

-- Clear the last message (does nothing on SR2)
function cleanercost_clear_message(sync)
	if Cleanercost_game == CLEANERCOST_SR2 then
		-- Can't clear messages in SR2
		return
	end

	if sync == nil or sync == SYNC_ALL then
		cleanercost_clear_message(SYNC_LOCAL)
		cleanercost_clear_message(SYNC_REMOTE)
	else
		if Cleanercost_last_message_handle[sync] ~= nil and Cleanercost_last_message_handle[sync] ~= -1 then
			message_remove(Cleanercost_last_message_handle[sync], false)
			Cleanercost_last_message_handle[sync] = -1
		end
	end
end

-- Show a message
-- msg: Message to display
-- duration: Number of seconds before this message disappears (default is 5 seconds)
-- player: Player to display this message (accepts both *_PLAYER and SYNC_* constants)
-- localize: true to enable localized message
function cleanercost_message(msg, duration, player, localize)
	if duration == nil then
		duration = 5
	end
	if localize == nil then
		localize = false
	end

	local sync = SYNC_ALL
	if (player == LOCAL_PLAYER) or (player == SYNC_LOCAL) then
		sync = SYNC_LOCAL
	end
	if (player == REMOTE_PLAYER) or (player == SYNC_REMOTE) then
		sync = SYNC_REMOTE
	end

	cleanercost_clear_message(sync)
	
	if Cleanercost_game == CLEANERCOST_SR2 then
		if sync == SYNC_ALL and localize == false then
			message(msg, duration)
		else
			mission_help_table_nag(msg, "", "", sync)
		end
	else
		Cleanercost_last_message_handle[sync] = message(msg, duration, localize, sync)
	end
end
